# Generated by roxygen2: do not edit by hand

S3method(cut_data_by_date,default)
S3method(cut_data_by_date,nb_sim_data)
S3method(cut_data_by_date,nb_sim_seasonal)
S3method(print,gsNBsummary)
S3method(print,mutze_test)
S3method(print,sample_size_nbinom_result)
S3method(print,sample_size_nbinom_summary)
S3method(summary,gsNB)
S3method(summary,sample_size_nbinom_result)
S3method(toInteger,gsDesign)
S3method(toInteger,gsNB)
export(blinded_ssr)
export(calculate_blinded_info)
export(check_gs_bound)
export(compute_info_at_time)
export(cut_completers)
export(cut_data_by_date)
export(cut_date_for_completers)
export(estimate_nb_mom)
export(get_analysis_date)
export(get_cut_date)
export(gsBoundSummary)
export(gsDesign)
export(gsNBCalendar)
export(mutze_test)
export(nb_sim)
export(nb_sim_seasonal)
export(sample_size_nbinom)
export(sfBetaDist)
export(sfCauchy)
export(sfExponential)
export(sfExtremeValue)
export(sfExtremeValue2)
export(sfGapped)
export(sfHSD)
export(sfLDOF)
export(sfLDPocock)
export(sfLinear)
export(sfLogistic)
export(sfNormal)
export(sfPoints)
export(sfPower)
export(sfStep)
export(sfTDist)
export(sfTrimmed)
export(sfTruncated)
export(sfXG1)
export(sfXG2)
export(sfXG3)
export(sim_gs_nbinom)
export(summarize_gs_sim)
export(toInteger)
export(unblinded_ssr)
import(data.table)
importFrom(MASS,glm.nb)
importFrom(data.table,as.data.table)
importFrom(gsDesign,gsBoundSummary)
importFrom(gsDesign,gsDesign)
importFrom(gsDesign,sfBetaDist)
importFrom(gsDesign,sfCauchy)
importFrom(gsDesign,sfExponential)
importFrom(gsDesign,sfExtremeValue)
importFrom(gsDesign,sfExtremeValue2)
importFrom(gsDesign,sfGapped)
importFrom(gsDesign,sfHSD)
importFrom(gsDesign,sfLDOF)
importFrom(gsDesign,sfLDPocock)
importFrom(gsDesign,sfLinear)
importFrom(gsDesign,sfLogistic)
importFrom(gsDesign,sfNormal)
importFrom(gsDesign,sfPoints)
importFrom(gsDesign,sfPower)
importFrom(gsDesign,sfStep)
importFrom(gsDesign,sfTDist)
importFrom(gsDesign,sfTrimmed)
importFrom(gsDesign,sfTruncated)
importFrom(gsDesign,sfXG1)
importFrom(gsDesign,sfXG2)
importFrom(gsDesign,sfXG3)
importFrom(simtrial,rpwexp_enroll)
importFrom(stats,coef)
importFrom(stats,fitted)
importFrom(stats,pnorm)
importFrom(stats,poisson)
importFrom(stats,qnorm)
importFrom(stats,rexp)
importFrom(stats,rgamma)
importFrom(stats,uniroot)
importFrom(stats,vcov)
importFrom(utils,tail)
