# gsDesignNB

<!-- badges: start -->
[![CRAN status](https://www.r-pkg.org/badges/version/gsDesignNB)](https://CRAN.R-project.org/package=gsDesignNB)
[![Codecov test coverage](https://codecov.io/gh/keaven/gsDesignNB/graph/badge.svg)](https://app.codecov.io/gh/keaven/gsDesignNB)
[![pkgdown](https://github.com/keaven/gsDesignNB/actions/workflows/pkgdown.yaml/badge.svg)](https://github.com/keaven/gsDesignNB/actions/workflows/pkgdown.yaml)
[![R-CMD-check](https://github.com/keaven/gsDesignNB/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/keaven/gsDesignNB/actions/workflows/R-CMD-check.yaml)
<!-- badges: end -->

gsDesignNB provides fixed design and group sequential design simulation for
recurrent event scenarios to be analyzed as a Poisson process or negative binomial model.
For group sequential design, the package can be easily used with the gsDesign package.
Key is the computation of statistical information at the time of analysis.

## Installation

You can install gsDesignNB from CRAN with:

```r
install.packages("gsDesignNB")
```

Or install the development version from GitHub with:

```r
remotes::install_github("keaven/gsDesignNB")
```

## Code style

This package follows the [tidyverse style guide](https://style.tidyverse.org/).
